@@ -26,20 +26,20 @@
 from __future__ import annotations
 from typing import TYPE_CHECKING
 
-from fabric_cf.actor.core.apis.i_delegation import IDelegation
-from fabric_cf.actor.core.apis.i_reservation import IReservation
-from fabric_cf.actor.core.apis.i_slice import ISlice
+from fabric_cf.actor.core.apis.abc_delegation import ABCDelegation
+from fabric_cf.actor.core.apis.abc_reservation_mixin import ABCReservationMixin
+from fabric_cf.actor.core.apis.abc_slice import ABCSlice
 from fabric_cf.actor.core.core.pool_manager import PoolManager
-from fabric_cf.actor.core.plugins.substrate.substrate import Substrate
+from fabric_cf.actor.core.plugins.substrate.substrate_mixin import SubstrateMixin
 
 if TYPE_CHECKING:
-    from fabric_cf.actor.core.core.actor import Actor
+    from fabric_cf.actor.core.core.actor import ActorMixin
     from fabric_cf.actor.core.plugins.handlers.handler_processor import HandlerProcessor
-    from fabric_cf.actor.core.apis.i_substrate_database import ISubstrateDatabase
+    from fabric_cf.actor.core.apis.abc_substrate_database import ABCSubstrateDatabase
 
 
-class AuthoritySubstrate(Substrate):
-    def __init__(self, *, actor: Actor, db: ISubstrateDatabase, handler_processor: HandlerProcessor):
+class AuthoritySubstrate(SubstrateMixin):
+    def __init__(self, *, actor: ActorMixin, db: ABCSubstrateDatabase, handler_processor: HandlerProcessor):
         super().__init__(actor=actor, db=db, handler_processor=handler_processor)
         self.pool_manager = None
         self.initialized = False
@@ -47,7 +47,6 @@ class AuthoritySubstrate(Substrate):
     def __getstate__(self):
         state = self.__dict__.copy()
         del state['logger']
-        del state['resource_delegation_factory']
         del state['actor']
         del state['initialized']
         del state['pool_manager']
@@ -73,11 +72,11 @@ class AuthoritySubstrate(Substrate):
     def get_pool_manager(self) -> PoolManager:
         return self.pool_manager
 
-    def revisit(self, *, slice_obj: ISlice = None, reservation: IReservation = None, delegation: IDelegation = None):
+    def revisit(self, *, slice_obj: ABCSlice = None, reservation: ABCReservationMixin = None, delegation: ABCDelegation = None):
         if slice_obj is not None and slice_obj.is_inventory():
             self.logger.debug("Recovering inventory slice")
             self.recover_inventory_slice(slice_obj=slice_obj)
 
-    def recover_inventory_slice(self, *, slice_obj: ISlice):
+    def recover_inventory_slice(self, *, slice_obj: ABCSlice):
         if slice_obj.get_graph_id() is not None:
             self.actor.load_model(graph_id=slice_obj.get_graph_id())
\ No newline at end of file
