@@ -25,21 +25,26 @@
 # Author: Komal Thareja (kthare10@renci.org)
 from __future__ import annotations
 
+import enum
 import threading
 import traceback
 from datetime import datetime
+from enum import Enum
 from typing import TYPE_CHECKING, Tuple, List
 
-from fim.graph.resources.neo4j_adm import Neo4jADMGraph
+from fim.graph.abc_property_graph import ABCPropertyGraphConstants
+from fim.graph.resources.abc_adm import ABCADMPropertyGraph
 from fim.pluggable import PluggableRegistry, PluggableType
 from fim.slivers.base_sliver import BaseSliver
-from fim.slivers.network_node import NodeSliver
+from fim.slivers.network_node import NodeSliver, NodeType
+from fim.slivers.network_link import NetworkLinkSliver
 
-from fabric_cf.actor.core.apis.i_broker_reservation import IBrokerReservation
-from fabric_cf.actor.core.apis.i_delegation import IDelegation
-from fabric_cf.actor.core.apis.i_reservation import IReservation
+from fabric_cf.actor.core.apis.abc_broker_reservation import ABCBrokerReservation
+from fabric_cf.actor.core.apis.abc_delegation import ABCDelegation
+from fabric_cf.actor.core.apis.abc_reservation_mixin import ABCReservationMixin
 from fabric_cf.actor.core.common.constants import Constants
-from fabric_cf.actor.core.common.exceptions import BrokerException
+from fabric_cf.actor.core.delegation.resource_ticket import ResourceTicketFactory
+from fabric_cf.actor.core.common.exceptions import BrokerException, ExceptionErrorCode
 from fabric_cf.actor.core.policy.broker_calendar_policy import BrokerCalendarPolicy
 from fabric_cf.actor.core.policy.fifo_queue import FIFOQueue
 from fabric_cf.actor.core.time.actor_clock import ActorClock
@@ -47,17 +52,29 @@ from fabric_cf.actor.core.time.term import Term
 from fabric_cf.actor.core.util.bids import Bids
 from fabric_cf.actor.core.util.reservation_set import ReservationSet
 from fabric_cf.actor.core.policy.inventory import Inventory
-from fabric_cf.actor.core.apis.i_client_reservation import IClientReservation
+from fabric_cf.actor.core.apis.abc_client_reservation import ABCClientReservation
 from fabric_cf.actor.fim.fim_helper import FimHelper
 from fabric_cf.actor.fim.plugins.broker.aggregate_bqm_plugin import AggregateBQMPlugin
 
 if TYPE_CHECKING:
-    from fabric_cf.actor.core.apis.i_broker import IBroker
+    from fabric_cf.actor.core.apis.abc_broker_mixin import ABCBrokerMixin
     from fabric_cf.actor.core.policy.inventory_for_type import InventoryForType
     from fabric_cf.actor.core.util.resource_type import ResourceType
     from fabric_cf.actor.core.kernel.resource_set import ResourceSet
 
 
+class BrokerAllocationAlgorithm(Enum):
+    FirstFit = enum.auto()
+    BestFit = enum.auto()
+    WorstFit = enum.auto()
+
+    def __repr__(self):
+        return self.name
+
+    def __str__(self):
+        return self.name
+
+
 class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
     """
         BrokerSimplerUnitsPolicy is a simple implementation of the broker policy interface.
@@ -78,7 +95,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
     #  How far in the future is the broker allocating resources
     ADVANCE_TIME = 3
 
-    def __init__(self, *, actor: IBroker = None):
+    def __init__(self, *, actor: ABCBrokerMixin = None):
         super().__init__(actor=actor)
         self.last_allocation = -1
         self.allocation_horizon = 0
@@ -145,7 +162,8 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
         self.combined_broker_model_graph_id = self.combined_broker_model.get_graph_id()
         self.logger.debug(f"Successfully loaded an Combined Broker Model Graph: {self.combined_broker_model_graph_id}")
         # TODO uncomment post complete integration
-        self.pluggable_registry.register_pluggable(t=PluggableType.Broker, p=AggregateBQMPlugin)
+        self.pluggable_registry.register_pluggable(t=PluggableType.Broker, p=AggregateBQMPlugin, actor=self.actor,
+                                                   logger=self.logger)
         self.logger.debug(f"Registered AggregateBQMPlugin")
 
     def initialize(self):
@@ -165,7 +183,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
         """
         self.inventory.add_inventory_by_type(rtype=resource_type, inventory=inventory)
 
-    def bind(self, *, reservation: IBrokerReservation) -> bool:
+    def bind(self, *, reservation: ABCBrokerReservation) -> bool:
         term = reservation.get_requested_term()
         self.logger.info("SlottedAgent bind arrived at cycle {} requested term {}".format(
             self.actor.get_current_cycle(), term))
@@ -176,7 +194,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
 
         return False
 
-    def bind_delegation(self, *, delegation: IDelegation) -> bool:
+    def bind_delegation(self, *, delegation: ABCDelegation) -> bool:
         try:
             self.lock.acquire()
             self.delegations[delegation.get_delegation_id()] = delegation
@@ -185,7 +203,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
 
         return False
 
-    def extend_broker(self, *, reservation: IBrokerReservation) -> bool:
+    def extend_broker(self, *, reservation: ABCBrokerReservation) -> bool:
         requested_term = reservation.get_requested_term()
         self.logger.info("SlottedAgent extend arrived at cycle {} requested term {}".format(
             self.actor.get_current_cycle(), requested_term))
@@ -211,7 +229,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
         extending = self.process_renewing(renewing=renewing, pending=pending)
         return Bids(ticketing=ReservationSet(), extending=extending)
 
-    def get_allocation(self, *, reservation: IBrokerReservation) -> int:
+    def get_allocation(self, *, reservation: ABCBrokerReservation) -> int:
         if not self.ready:
             self.error(message="Agent not ready to accept bids")
 
@@ -228,7 +246,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
 
         return start
 
-    def get_approved_term(self, *, reservation: IBrokerReservation) -> Term:
+    def get_approved_term(self, *, reservation: ABCBrokerReservation) -> Term:
         return Term(start=reservation.get_requested_term().get_start_time(),
                     end=reservation.get_requested_term().get_end_time(),
                     new_start=reservation.get_requested_term().get_new_start_time())
@@ -236,7 +254,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
     def get_next_allocation(self, *, cycle: int) -> int:
         return self.last_allocation + self.CALL_INTERVAL
 
-    def get_renew(self, *, reservation: IClientReservation) -> int:
+    def get_renew(self, *, reservation: ABCClientReservation) -> int:
         new_start_cycle = self.actor.get_actor_clock().cycle(when=reservation.get_term().get_end_time()) + 1
         return new_start_cycle - self.ADVANCE_TIME - self.CLOCK_SKEW
 
@@ -304,7 +322,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
         requests = self.calendar.get_all_requests(cycle=advance_cycle)
 
         if (requests is None or requests.size() == 0) and (self.queue is None or self.queue.size() == 0):
-            self.logger.debug(f"request: {requests} queue: {self.queue}")
+            self.logger.debug(f"requests: {requests} queue: {self.queue}")
             self.logger.debug(f"no requests for auction start cycle {start_cycle}")
             return
 
@@ -359,8 +377,8 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
                     continue
 
                 if not reservation.is_failed():
-                    reservation.fail(f"Insufficient resources for specified start time, Failing reservation: "
-                                     f"{reservation.get_reservation_id()}")
+                    reservation.fail(message=f"Insufficient resources for specified start time, Failing reservation: "
+                                             f"{reservation.get_reservation_id()}")
 
     def allocate_queue(self, *, start_cycle: int):
         if self.queue is None:
@@ -384,7 +402,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
             else:
                 self.queue.remove(reservation=reservation)
 
-    def ticket(self, *, reservation: IBrokerReservation, node_id_to_reservations: dict) -> Tuple[bool, dict]:
+    def ticket(self, *, reservation: ABCBrokerReservation, node_id_to_reservations: dict) -> Tuple[bool, dict]:
         self.logger.debug(f"cycle: {self.actor.get_current_cycle()} new ticket request: "
                           f"{reservation}/{type(reservation).__name__}")
 
@@ -412,31 +430,67 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
 
         return False, node_id_to_reservations
 
-    def ticket_inventory(self, *, reservation: IBrokerReservation, inv: InventoryForType, term: Term,
+    def __candidate_nodes(self, sliver: NodeSliver) -> List[str]:
+        """
+        Identify candidate worker nodes in this site that have at least
+        as many needed components as in the sliver.
+        """
+        node_props = {ABCPropertyGraphConstants.PROP_SITE: sliver.site,
+                      ABCPropertyGraphConstants.PROP_TYPE: str(NodeType.Server)}
+        return self.combined_broker_model.get_matching_nodes_with_components(
+            label=ABCPropertyGraphConstants.CLASS_NetworkNode,
+            props=node_props,
+            comps=sliver.attached_components_info)
+
+    def __candidate_links(self, sliver: NetworkLinkSliver) -> List[str]:
+        pass
+
+    def ticket_inventory(self, *, reservation: ABCBrokerReservation, inv: InventoryForType, term: Term,
                          node_id_to_reservations: dict) -> Tuple[bool, dict]:
         try:
             rset = reservation.get_requested_resources()
             needed = rset.get_units()
 
-            # TODO - Slice Node to BQM Node mapping - remove hardcoding
-            node_id = 'HX7LQ53'
-            # TODO - End
-            if node_id is None:
-                raise BrokerException(f"Unable to find node_id {node_id} for reservation# {reservation}")
+            # for network node slivers
+            # find a list of candidate worker nodes that satisfy the requirements based on delegated
+            # capacities within the site
+            # for network link slivers
+            # orchestrator needs to provide a map to CBM guid of the node representing the
+            # intended link (and possibly interfaces connected to it)
 
-            graph_node = self.get_node_from_graph(node_id=node_id)
+            res_sliver = rset.get_sliver()
 
-            existing_reservations = self.get_existing_reservations(node_id=node_id,
-                                                                   node_id_to_reservations=node_id_to_reservations)
+            if isinstance(res_sliver, NodeSliver):
+                node_id_list = self.__candidate_nodes(res_sliver)
+            elif isinstance(res_sliver, NetworkLinkSliver):
+                node_id_list = self.__candidate_links(res_sliver)
+            else:
+                self.logger.error(f'Reservation {reservation} sliver type is neither Node, nor NetworkLink')
+                raise BrokerException(msg=f"Reservation sliver type is neither Node "
+                                      f"nor NetworkLink for reservation# {reservation}")
 
-            delegation_id, sliver = inv.allocate(reservation=reservation, graph_id=self.combined_broker_model_graph_id,
-                                                 graph_node=graph_node, existing_reservations=existing_reservations)
+            # no candidate nodes found
+            if len(node_id_list) == 0:
+                return False, node_id_to_reservations
+
+            delegation_id = None
+            sliver = None
+            # FIXME: walk the list to find First/Best/Worst fit
+            if self.get_algorithm_type().lower() == BrokerAllocationAlgorithm.FirstFit.name.lower():
+                delegation_id, sliver = self.__find_first_fit(node_id_list=node_id_list,
+                                                              node_id_to_reservations=node_id_to_reservations,
+                                                              inv=inv, reservation=reservation)
+            else:
+                raise BrokerException(error_code=ExceptionErrorCode.NOT_SUPPORTED,
+                                      msg=f"Broker currently only supports First Fit")
 
             if delegation_id is not None:
                 delegation = self.actor.get_delegation(did=delegation_id)
                 reservation = self.issue_ticket(reservation=reservation, units=needed, rtype=rset.get_type(), term=term,
                                                 source=delegation, sliver=sliver)
 
+                node_map = sliver.get_node_map()
+                node_id = node_map[1]
                 if node_id_to_reservations.get(node_id, None) is None:
                     node_id_to_reservations[node_id] = ReservationSet()
                 node_id_to_reservations[node_id].add(reservation=reservation)
@@ -447,16 +501,55 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
             reservation.fail(message=str(e))
         return False, node_id_to_reservations
 
-    def extend_private(self, *, reservation: IBrokerReservation, inv: InventoryForType, term: Term):
-        pass
+    def __find_first_fit(self, node_id_list: List[str], node_id_to_reservations: dict, inv: InventoryForType,
+                         reservation: ABCBrokerReservation) -> Tuple[str, BaseSliver]:
+        delegation_id = None
+        sliver = None
+        self.logger.debug(f"Possible candidates to serve res# {reservation} candidates# {node_id_list}")
+        for node_id in node_id_list:
+            try:
+                self.logger.debug(f"Attempting to allocate res# {reservation} via graph_node# {node_id}")
+                graph_node = self.get_node_from_graph(node_id=node_id)
 
-    def issue_ticket(self, *, reservation: IBrokerReservation, units: int, rtype: ResourceType,
-                     term: Term, source: IDelegation, sliver: BaseSliver) -> IBrokerReservation:
+                existing_reservations = self.get_existing_reservations(node_id=node_id,
+                                                                       node_id_to_reservations=node_id_to_reservations)
+
+                delegation_id, sliver = inv.allocate(reservation=reservation,
+                                                     graph_id=self.combined_broker_model_graph_id,
+                                                     graph_node=graph_node, existing_reservations=existing_reservations)
+
+                if delegation_id is not None and sliver is not None:
+                    break
+            except BrokerException as e:
+                if e.error_code == ExceptionErrorCode.INSUFFICIENT_RESOURCES:
+                    self.logger.error(f"Exception occurred: {e}")
+                else:
+                    raise e
+
+        return delegation_id, sliver
+
+    def extend_private(self, *, reservation: ABCBrokerReservation, inv: InventoryForType, term: Term):
+        try:
+            self.logger.debug(f"Extend private initiated for {reservation}")
+            requested_resources = reservation.get_requested_resources()
+            needed = requested_resources.get_units()
+            current = reservation.get_resources().get_units()
+            if needed == current:
+                self.issue_ticket(reservation=reservation, units=needed, rtype=requested_resources.get_type(),
+                                  term=term, source=reservation.get_source(), sliver=reservation.get_resources().sliver)
+            else:
+                self.logger.error(f"Failed to satisfy the extend for reservation# {reservation}")
+        except Exception as e:
+            self.logger.error(e)
+            self.logger.error(traceback.format_exc())
+            reservation.fail(exception=e)
+
+    def issue_ticket(self, *, reservation: ABCBrokerReservation, units: int, rtype: ResourceType,
+                     term: Term, source: ABCDelegation, sliver: BaseSliver) -> ABCBrokerReservation:
 
         # make the new delegation
-        resource_delegation = self.actor.get_plugin().get_resource_delegation_factory().make_delegation(units=units,
-                                                                                                        term=term,
-                                                                                                        rtype=rtype)
+        resource_delegation = ResourceTicketFactory.create(issuer=self.actor.get_identity().get_guid(), units=units,
+                                                           term=term, rtype=rtype)
 
         # extract a new resource set
         mine = self.extract(source=source, delegation=resource_delegation)
@@ -474,11 +567,11 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
             reservation.set_bid_pending(value=False)
         else:
             if mine is None:
-                raise BrokerException("There was an error extracting a ticket from the source delegation")
+                raise BrokerException(msg="There was an error extracting a ticket from the source delegation")
         return reservation
 
     def release(self, *, reservation):
-        if isinstance(reservation, IBrokerReservation):
+        if isinstance(reservation, ABCBrokerReservation):
             self.logger.debug("Broker reservation")
             super().release(reservation=reservation)
             if reservation.is_closed_in_priming():
@@ -493,7 +586,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
                                        slice_id=str(reservation.get_slice_id()),
                                        rset=reservation.get_resources(),
                                        term=reservation.get_term())
-        elif isinstance(reservation, IClientReservation):
+        elif isinstance(reservation, ABCClientReservation):
             self.logger.debug("Client reservation")
             super().release(reservation=reservation)
             status = self.inventory.remove(source=reservation)
@@ -507,7 +600,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
                 return
             inv = self.inventory.get(resource_type=rset.get_type())
             if inv is None:
-                raise BrokerException("Cannot release resources: missing inventory")
+                raise BrokerException(msg="Cannot release resources: missing inventory")
         except Exception as e:
             self.logger.error(f"release resources {e}")
 
@@ -549,15 +642,16 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
             query_level = int(query_level)
 
         if query_action is None:
-            raise BrokerException(Constants.NOT_SPECIFIED_PREFIX.format(Constants.QUERY_ACTION))
+            raise BrokerException(error_code=ExceptionErrorCode.INVALID_ARGUMENT,
+                                  msg=f"query_action {query_action}")
 
         if query_action != Constants.QUERY_ACTION_DISCOVER_POOLS:
-            raise BrokerException(f"Invalid Query Action '{query_action}' specified")
+            raise BrokerException(error_code=ExceptionErrorCode.INVALID_ARGUMENT,
+                                  msg=f"query_action {query_action}")
 
         try:
             self.lock.acquire()
             if self.combined_broker_model is not None:
-                # TODO pass in level while getting BQM
                 graph = self.combined_broker_model.get_bqm(query_level=query_level)
                 result[Constants.BROKER_QUERY_MODEL] = graph.serialize_graph()
                 result[Constants.QUERY_RESPONSE_STATUS] = "True"
@@ -574,7 +668,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
         self.logger.debug("Returning Query Result: {}".format(result))
         return result
 
-    def donate_delegation(self, *, delegation: IDelegation):
+    def donate_delegation(self, *, delegation: ABCDelegation):
         """
         Donate an incoming delegation by merging to CBM;
         We take snapshot of CBM before merge, and rollback to snapshot in case merge fails
@@ -598,7 +692,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
         finally:
             self.lock.release()
 
-    def closed_delegation(self, *, delegation: IDelegation):
+    def closed_delegation(self, *, delegation: ABCDelegation):
         """
         Close a delegation by un-merging from CBM
         We take snapshot of CBM before un-merge, and rollback to snapshot in case un-merge fails
@@ -635,7 +729,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
         finally:
             self.lock.release()
 
-    def get_existing_reservations(self, node_id: str, node_id_to_reservations: dict) -> List[IReservation]:
+    def get_existing_reservations(self, node_id: str, node_id_to_reservations: dict) -> List[ABCReservationMixin]:
         """
         Get existing reservations which are served by CBM node identified by node_id
         :param node_id:
@@ -673,7 +767,7 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
             for inv in self.inventory.map.values():
                 inv.set_logger(logger=logger)
 
-    def merge_adm(self, *, adm_graph: Neo4jADMGraph):
+    def merge_adm(self, *, adm_graph: ABCADMPropertyGraph):
         """
         Merge delegation model in CBM
         :param adm_graph: ADM
@@ -713,6 +807,13 @@ class BrokerSimplerUnitsPolicy(BrokerCalendarPolicy):
                 self.combined_broker_model.rollback(graph_id=snapshot_graph_id)
             raise e
 
+    def get_algorithm_type(self) -> str:
+        if self.properties is not None:
+            algo_str = self.properties.get(Constants.ALGORITHM, None)
+            if algo_str is not None:
+                return algo_str
+        return BrokerAllocationAlgorithm.FirstFit.name
+
 
 if __name__ == '__main__':
     policy = BrokerSimplerUnitsPolicy()
