@@ -30,8 +30,8 @@ from fim.slivers.base_sliver import BaseSliver
 from fim.slivers.network_node import NodeSliver
 from fim.user import Capacities
 
-from fabric_cf.actor.core.apis.i_authority_reservation import IAuthorityReservation
-from fabric_cf.actor.core.apis.i_reservation import IReservation
+from fabric_cf.actor.core.apis.abc_authority_reservation import ABCAuthorityReservation
+from fabric_cf.actor.core.apis.abc_reservation_mixin import ABCReservationMixin
 from fabric_cf.actor.core.common.constants import Constants
 from fabric_cf.actor.core.common.exceptions import AuthorityException
 from fabric_cf.actor.core.core.unit import Unit
@@ -48,7 +48,7 @@ class NetworkNodeControl(ResourceControl):
     Resource Control for Network Node
     """
     def __check_capacities(self, *, rid: ID, requested_capacities: Capacities, available_capacities: Capacities,
-                           existing_reservations: List[IReservation]):
+                           existing_reservations: List[ABCReservationMixin]):
         """
         Check if the allocated capacities by the broker can be assigned
         :param rid: reservation id
@@ -92,7 +92,7 @@ class NetworkNodeControl(ResourceControl):
                                   f"Disk: [{requested_capacities.disk}/{available_disk}]")
 
     def __check_components(self, *, rid: ID, requested_components: AttachedComponentsInfo, graph_node: BaseSliver,
-                           existing_reservations: List[IReservation]):
+                           existing_reservations: List[ABCReservationMixin]):
         """
         Check if the allocated components by the broker can be assigned
         :param rid: reservation id
@@ -152,8 +152,8 @@ class NetworkNodeControl(ResourceControl):
                                 f"in graph {graph_node.node_id}"
                                 f"is already assigned to reservation# {reservation}")
 
-    def assign(self, *, reservation: IAuthorityReservation, delegation_name: str,
-               graph_node: BaseSliver, existing_reservations: List[IReservation]) -> ResourceSet:
+    def assign(self, *, reservation: ABCAuthorityReservation, delegation_name: str,
+               graph_node: BaseSliver, existing_reservations: List[ABCReservationMixin]) -> ResourceSet:
         """
         Assign a reservation
         :param reservation: reservation
@@ -206,18 +206,20 @@ class NetworkNodeControl(ResourceControl):
                                     existing_reservations=existing_reservations)
 
             self.logger.debug(f"Slice properties: {reservation.get_slice().get_config_properties()}")
-            unit = Unit(uid=ID(), rid=reservation.get_reservation_id(), slice_id=reservation.get_slice_id(),
+            unit = Unit(rid=reservation.get_reservation_id(), slice_id=reservation.get_slice_id(),
                         actor_id=self.authority.get_guid(), sliver=requested, rtype=resource_type,
                         properties=reservation.get_slice().get_config_properties())
-            gained = UnitSet(plugin=self.authority.get_plugin(), units={unit.uid: unit})
+            gained = UnitSet(plugin=self.authority.get_plugin(), units={unit.reservation_id: unit})
         else:
-            raise AuthorityException("Modify not supported")
+            # FIX ME: handle modify
+            self.logger.info(f"Extend Lease for now, no modify supported res# {reservation}")
+            return current
 
         result = ResourceSet(gained=gained, lost=lost, rtype=resource_type)
         result.set_sliver(sliver=requested)
         return result
 
-    def revisit(self, *, reservation: IReservation):
+    def revisit(self, *, reservation: ABCReservationMixin):
         return
 
     def free(self, *, uset: dict):
