@@ -6,12 +6,14 @@ from fabric_cf.orchestrator.swagger_server import util
 from fabric_cf.orchestrator.swagger_server.response import resources_controller as rc
 
 
-def resources_get():  # noqa: E501
+def resources_get(level):  # noqa: E501
     """Retrieve a listing and description of available resources
 
     Retrieve a listing and description of available resources # noqa: E501
 
+    :param level: Level of details
+    :type level: int
 
     :rtype: Success
     """
-    return rc.resources_get()
+    return rc.resources_get(level)
